==> cloud-3.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/k8s/src/Plugin/Block/K8sNamespaceCostsBlock.php <==
<?php

namespace Drupal\k8s\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\k8s\Controller\K8sCostsControllerBase;

/**
 * Provides a block of the costs.
 *
 * @Block(
 *   id = "k8s_namespace_costs",
 *   admin_label = @Translation("K8s Namespace Costs"),
 *   category = @Translation("K8s")
 * )
 */
class K8sNamespaceCostsBlock extends K8sBaseBlock {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'display_view_k8s_namespace_list_only' => 1,
      'aws_cloud_ec2_cost_type' => 'ri_one_year',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $controller = $this->classResolver->getInstanceFromDefinition(K8sCostsControllerBase::class);

    $form['display_view_k8s_namespace_list_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display this block in K8s Namespace list page and K8s Project Content page only'),
      '#default_value' => $this->configuration['display_view_k8s_namespace_list_only'],
    ];

    $form['aws_cloud_ec2_cost_type'] = [
      '#type' => 'select',
      '#title' => $this->t('AWS Cloud EC2 Cost Type'),
      '#options' => $controller->getEc2CostTypes(),
      '#default_value' => $this->configuration['aws_cloud_ec2_cost_type'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {

    $this->configuration['display_view_k8s_namespace_list_only']
      = $form_state->getValue('display_view_k8s_namespace_list_only');

    $this->configuration['aws_cloud_ec2_cost_type']
      = $form_state->getValue('aws_cloud_ec2_cost_type');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {

    // If aws_cloud module is not enabled; do nothing.
    if (!$this->moduleHandler->moduleExists('aws_cloud')) {
      return [
        '#type' => 'markup',
        '#markup' => $this->t('This block requires the AWS Cloud
        module to be enabled.'),
      ];
    }

    // If display_view_k8s_namespace_list_only is checked, do nothing.
    $route_name = $this->routeMatch->getRouteName();
    if ($route_name !== 'view.k8s_namespace.list'
      && $route_name !== 'entity.cloud_project.canonical'
      && $this->configuration['display_view_k8s_namespace_list_only']) {
      return [];
    }

    $nodes = [];
    $namespaces = [];
    $cloud_contexts = [];

    $cloud_context = $this->routeMatch->getParameter('cloud_context');
    $cloud_project = $this->routeMatch->getParameter('cloud_project');

    if (!empty($cloud_project)) {
      $k8s_clusters = $cloud_project->get('field_k8s_clusters')->getValue();
      foreach ($k8s_clusters ?: [] as $k8s_cluster) {
        $cloud_contexts[] = $k8s_cluster['value'];
      }
    }
    elseif (!empty($cloud_context)) {
      $cloud_contexts[] = $cloud_context;
    }

    // If cloud_context is passed, filter entities with it.
    if (!empty($cloud_contexts)) {
      foreach ($cloud_contexts ?: [] as $cluster) {
        $nodes = array_merge($nodes, $this->entityTypeManager
          ->getStorage('k8s_node')->loadByProperties(
            [
              'cloud_context' => $cluster,
            ]
          ));
        $namespaces = array_merge($namespaces, $this->entityTypeManager
          ->getStorage('k8s_namespace')->loadByProperties(
            [
              'cloud_context' => $cluster,
            ]
          ));
      }

      // If nodes or namespaces are empty, ask the user
      // to try updating the cloud_context to bring in
      // the latest data.
      if (empty($nodes) || empty($namespaces)) {
        $message = $this->t('Nodes and/or namespaces not found for K8s Namespace Cost block.');
        $this->setUpdateMessage($cloud_context, $message);
      }
    }
    else {
      // Load all nodes and namespaces.
      $node_ids = $this->entityTypeManager
        ->getStorage('k8s_node')->getQuery()
        ->execute();
      $nodes = $this->entityTypeManager
        ->getStorage('k8s_node')->loadMultiple($node_ids);

      $namespace_ids = $this->entityTypeManager
        ->getStorage('k8s_namespace')->getQuery()
        ->execute();
      $namespaces = $this->entityTypeManager
        ->getStorage('k8s_namespace')->loadMultiple($namespace_ids);
    }

    $build = [];

    $total_costs = $this->k8sService->getTotalCosts($nodes, $this->configuration['aws_cloud_ec2_cost_type'], $this->refresh);

    // $cpu_capacity = $this->getCpuCapacity($nodes);
    $cpu_capacity = array_sum(array_map(static function ($node) {
      return $node->getCpuCapacity();
    }, $nodes));

    $memory_capacity = array_sum(array_map(static function ($node) {
      return $node->getMemoryCapacity();
    }, $nodes));

    $pod_capacity = array_sum(array_map(static function ($node) {
      return $node->getPodsCapacity();
    }, $nodes));

    // Get row data.
    $rows = [];
    foreach ($namespaces ?: [] as $namespace) {
      $pods = $this->entityTypeManager
        ->getStorage('k8s_pod')->loadByProperties([
          'cloud_context' => $namespace->getCloudContext(),
          'namespace' => $namespace->getName(),
        ]
      );

      $row = [];
      if (!empty($cloud_project)) {
        $this->cloudConfigPluginManager->setCloudContext($namespace->getCloudContext());
        $cloud_config = $this->cloudConfigPluginManager->loadConfigEntity();
        $route = $this->cloudConfigPluginManager->getInstanceCollectionTemplateName();

        $row['k8s_cluster'] = [
          'data' => [
            '#type' => 'link',
            '#url' => Url::fromRoute($route, ['cloud_context' => $namespace->getCloudContext()]),
            '#title' => $cloud_config->getName(),
          ],
        ];
      }

      $row['namespace'] = [
        'data' => [
          '#type' => 'link',
          '#title' => $namespace->getName(),
          '#url' => Url::fromRoute(
            'entity.k8s_namespace.canonical',
            [
              'cloud_context' => $namespace->getCloudContext(),
              'k8s_namespace' => $namespace->id(),
            ]
          ),
        ],
      ];

      $cpu_usage = array_sum(array_map(static function ($pod) {
        return $pod->getCpuUsage();
      }, $pods));

      $memory_usage = array_sum(array_map(static function ($pod) {
        return $pod->getMemoryUsage();
      }, $pods));

      $pod_usage = count($pods);

      $costs = $total_costs > 0 ? ($cpu_usage / $cpu_capacity + $memory_usage / $memory_capacity + $pod_usage / $pod_capacity) / 3 * $total_costs : 0;

      $row['costs'] = [
        'data' => $total_costs > 0 ? $this->k8sService->formatCosts($costs, $total_costs) : 0,
        'value' => $costs,
      ];
      $row['cpu_usage'] = [
        'data' => $cpu_capacity > 0 ? $this->k8sService->formatCpuUsage($cpu_usage, $cpu_capacity) : 0,
        'value' => $cpu_usage,
      ];
      $row['memory_usage'] = [
        'data' => $memory_capacity > 0 ? $this->k8sService->formatMemoryUsage($memory_usage, $memory_capacity) : 0,
        'value' => $memory_usage,
      ];
      $row['pod_usage'] = [
        'data' => $pod_capacity > 0 ? $this->k8sService->formatPodUsage($pod_usage, $pod_capacity) : 0,
        'value' => $pod_usage,
      ];

      $rows[] = ['data' => $row];
    }

    $headers = [];

    if (!empty($cloud_project)) {
      $headers['k8s_cluster'] = [
        'data' => $this->t('K8s Cluster'),
        'field' => 'k8s_cluster',
      ];
    }

    $headers += [
        ['data' => $this->t('Namespace'), 'field' => 'namespace'],
        ['data' => $this->t('Total Costs ($)'), 'field' => 'costs'],
        ['data' => $this->t('CPU (Usage)'), 'field' => 'cpu_usage'],
        ['data' => $this->t('Memory (Usage)'), 'field' => 'memory_usage'],
        ['data' => $this->t('Pods Allocation'), 'field' => 'pod_usage'],
    ];

    $sort = $this->request->get('sort');
    $order = $this->request->get('order');

    $order_field = NULL;
    foreach ($headers ?: [] as $header) {
      if ($header['data']->render() === $order) {
        $order_field = $header['field'];
      }
    }

    // Get sort and order parameters.
    if (empty($sort)) {
      $sort = 'asc';
    }
    if (empty($order_field)) {
      if (!empty($cloud_project)) {
        $order_field = 'k8s_cluster';
      }
      else {
        $order_field = 'namespace';
      }
    }

    // Sort data.
    usort($rows, static function ($a, $b) use ($sort, $order_field) {
      $result = 1;
      if ($sort === 'desc') {
        $result *= -1;
      }

      if ($order_field === 'k8s_cluster' && $a['data'][$order_field]['data']['#title'] === $b['data'][$order_field]['data']['#title']) {
        $order_field = 'namespace';
        $result = 1;
      }

      if ($order_field === 'k8s_cluster' || $order_field === 'namespace') {
        $result *= $a['data'][$order_field]['data']['#title'] < $b['data'][$order_field]['data']['#title'] ? -1 : 1;
      }
      else {
        $value_a = floatval($a['data'][$order_field]['value']);
        $value_b = floatval($b['data'][$order_field]['value']);
        $result *= $value_a < $value_b ? -1 : 1;
      }

      return $result;
    });

    $items_per_page_options = cloud_get_views_items_options();
    $items_per_page_options['All'] = '- All -';

    $items_per_page = $this->request->get('cost_items_per_page');
    if (empty($items_per_page) || !array_key_exists($items_per_page, $items_per_page_options)) {
      // Set default value.
      $items_per_page = 50;
    }

    $current_rows_chunk = $rows;
    if ($items_per_page !== 'All') {
      // Set pager's ID as 10.
      $current_page = $this->pagerManager
        ->createPager(count($rows), $items_per_page, 10)
        ->getCurrentPage();
      $rows_chunks = array_chunk($rows, $items_per_page);
      $current_rows_chunk = $rows_chunks[$current_page];
    }

    $table = [
      '#type' => 'table',
      '#header' => $headers,
      '#rows' => $current_rows_chunk,
    ];

    $controller = $this->classResolver->getInstanceFromDefinition(K8sCostsControllerBase::class);
    $cost_types = $controller->getEc2CostTypes();
    $cost_type = $this->configuration['aws_cloud_ec2_cost_type'];
    $build['k8s_namespace_costs'] = [
      '#type' => 'details',
      '#title' => $this->t('Namespace Costs') . " ($cost_types[$cost_type])",
      '#open' => TRUE,
    ];

    $build['k8s_namespace_costs']['container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['form--inline', 'form-inline', 'clearfix'],
      ],
    ];

    $build['k8s_namespace_costs']['container']['cost_items_per_page'] = [
      '#type' => 'select',
      '#name' => 'cost_items_per_page',
      '#title' => $this->t('Items per page'),
      '#value' => $items_per_page,
      '#options' => $items_per_page_options,
    ];

    $build['k8s_namespace_costs']['container']['cost_apply'] = [
      '#type' => 'button',
      '#name' => 'cost_apply',
      '#value' => $this->t('Apply'),
    ];

    $build['k8s_namespace_costs']['table'] = $table;
    if ($items_per_page !== 'All') {
      $build['k8s_namespace_costs']['pager'] = [
        '#type' => 'pager',
        '#element' => 10,
        '#tags' => [
          $this->t('« First'),
          $this->t('‹‹'),
          '',
          $this->t('››'),
          $this->t('Last »'),
        ],
      ];
    }

    $build['#attached']['library'][] = 'k8s/k8s_namespace_costs_block';

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    $this->killSwitch->trigger();
    // BigPipe/#cache/max-age is breaking my block javascript
    // https://www.drupal.org/forum/support/module-development-and-code-questions/2016-07-17/bigpipecachemax-age-is-breaking-my
    // "a slight delay of a second or two before the charts are built.
    // That seems to work, though it is a janky solution.".
    return $this->moduleHandler->moduleExists('big_pipe') ? 1 : 0;
  }

}

==> cloud-4.0.0-beta1.tar.gz: cloud/modules/cloud_service_providers/k8s/src/Plugin/Block/K8sNamespaceCostsBlock.php <==
<?php

namespace Drupal\k8s\Plugin\Block;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\k8s\Controller\K8sCostsControllerBase;
use Drupal\Component\Utility\Html;

/**
 * Provides a block of the costs.
 *
 * @Block(
 *   id = "k8s_namespace_costs",
 *   admin_label = @Translation("K8s Namespace Costs"),
 *   category = @Translation("K8s")
 * )
 */
class K8sNamespaceCostsBlock extends K8sBaseBlock {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return (parent::defaultConfiguration() ?: []) + [
      'display_view_k8s_namespace_list_only' => 1,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state): array {
    $form = parent::blockForm($form, $form_state);

    $form['display_view_k8s_namespace_list_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display this block in K8s Namespace list page and K8s Project Content page only'),
      '#default_value' => $this->configuration['display_view_k8s_namespace_list_only'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state): void {
    parent::blockSubmit($form, $form_state);

    $this->configuration['display_view_k8s_namespace_list_only']
      = $form_state->getValue('display_view_k8s_namespace_list_only');
  }

  /**
   * {@inheritdoc}
   */
  public function build(): array {

    // If aws_cloud module is not enabled; do nothing.
    if (!$this->moduleHandler->moduleExists('aws_cloud')) {
      return [
        '#type' => 'markup',
        '#markup' => $this->t('This block requires the AWS Cloud
        module to be enabled.'),
      ];
    }

    // If display_view_k8s_namespace_list_only is checked, do nothing.
    $route_name = $this->routeMatch->getRouteName();
    if ($route_name !== 'view.k8s_namespace.list'
      && $route_name !== 'entity.cloud_project.canonical'
      && $this->configuration['display_view_k8s_namespace_list_only']) {
      return [];
    }

    $nodes = [];
    $namespaces = [];
    $cloud_contexts = [];

    $cloud_context = $this->routeMatch->getParameter('cloud_context');
    $cloud_project = $this->routeMatch->getParameter('cloud_project');

    if (!empty($cloud_project)) {
      $k8s_clusters = $cloud_project->get('field_k8s_clusters')->getValue();
      foreach ($k8s_clusters ?: [] as $k8s_cluster) {
        $cloud_contexts[] = $k8s_cluster['value'];
      }
    }
    elseif (!empty($cloud_context)) {
      $cloud_contexts[] = $cloud_context;
    }

    // If cloud_context is passed, filter entities with it.
    if (!empty($cloud_contexts)) {
      foreach ($cloud_contexts ?: [] as $cluster) {
        $nodes = array_merge($nodes, $this->loadEntities('k8s_node', [
          'cloud_context' => $cluster,
        ], FALSE));
        $namespaces = array_merge($namespaces, $this->loadEntities('k8s_namespace', [
          'cloud_context' => $cluster,
        ]));
      }

      // If nodes or namespaces are empty, ask the user
      // to try updating the cloud_context to bring in
      // the latest data.
      if (empty($nodes) || empty($namespaces)) {
        $message = $this->t('Nodes and/or namespaces not found for K8s Namespace Cost block.');
        $this->setUpdateMessage($cloud_context, $message);
      }
    }
    else {
      // Load all nodes and namespaces.
      $nodes = $this->loadEntities('k8s_node', [], FALSE);
      $namespaces = $this->loadEntities('k8s_namespace');
    }

    if (empty($nodes) || empty($namespaces)) {
      return [];
    }

    $build = [];

    $block_id = Html::getUniqueId($this->getPluginId());
    $params = $this->request->get($block_id, []);

    $controller = $this->classResolver->getInstanceFromDefinition(K8sCostsControllerBase::class);
    $cost_type_list = $controller->getEc2CostTypes();

    $default_cost_type = !empty($params['cost_type'])
      ? $params['cost_type']
      : $this->getDefaultCostType($cloud_contexts);

    $cost_type = array_key_exists($default_cost_type, $cost_type_list)
      ? $default_cost_type
      : self::DEFAULT_COST_TYPE;

    $total_costs = $this->k8sService->getTotalCosts($nodes, $cost_type, $this->refresh);

    // $cpu_capacity = $this->getCpuCapacity($nodes);
    $cpu_capacity = array_sum(array_map(static function ($node) {
      return $node->getCpuCapacity();
    }, $nodes));

    $memory_capacity = array_sum(array_map(static function ($node) {
      return $node->getMemoryCapacity();
    }, $nodes));

    $pod_capacity = array_sum(array_map(static function ($node) {
      return $node->getPodsCapacity();
    }, $nodes));

    // Get row data.
    $rows = [];
    $precision = $cost_type === 'on_demand_hourly' ? 4 : 2;
    foreach ($namespaces ?: [] as $namespace) {
      $pods = $this->loadEntities('k8s_pod', [
        'cloud_context' => $namespace->getCloudContext(),
        'namespace' => $namespace->getName(),
      ], FALSE);

      $row = [];
      if (!empty($cloud_project)) {
        $this->cloudConfigPluginManager->setCloudContext($namespace->getCloudContext());
        $cloud_config = $this->cloudConfigPluginManager->loadConfigEntity();
        $route = $this->cloudConfigPluginManager->getInstanceCollectionTemplateName();

        $row['k8s_cluster'] = [
          'data' => [
            '#type' => 'link',
            '#url' => Url::fromRoute($route, ['cloud_context' => $namespace->getCloudContext()]),
            '#title' => $cloud_config->getName(),
          ],
        ];
      }

      $row['namespace'] = [
        'data' => [
          '#type' => 'link',
          '#title' => $namespace->getName(),
          '#url' => Url::fromRoute(
            'entity.k8s_namespace.canonical',
            [
              'cloud_context' => $namespace->getCloudContext(),
              'k8s_namespace' => $namespace->id(),
            ]
          ),
        ],
      ];

      $cpu_usage = array_sum(array_map(static function ($pod) {
        return $pod->getCpuUsage();
      }, $pods));

      $memory_usage = array_sum(array_map(static function ($pod) {
        return $pod->getMemoryUsage();
      }, $pods));

      $pod_usage = count($pods);

      $cpu_usage_ratio = $cpu_capacity > 0 ? $cpu_usage / $cpu_capacity : 0;
      $memory_capacity_ratio = $memory_capacity > 0 ? $memory_usage / $memory_capacity : 0;
      $pod_capacity_ratio = $pod_capacity > 0 ? $pod_usage / $pod_capacity : 0;
      $costs = $total_costs > 0 ? ($cpu_usage_ratio + $memory_capacity_ratio + $pod_capacity_ratio) / 3 * $total_costs : 0;

      $row['costs'] = [
        'data' => $this->k8sService->formatCosts($costs, $total_costs, $precision),
        'value' => $costs,
      ];
      $row['cpu_usage'] = [
        'data' => $this->k8sService->formatCpuUsage($cpu_usage, $cpu_capacity),
        'value' => $cpu_usage,
      ];
      $row['memory_usage'] = [
        'data' => $this->k8sService->formatMemoryUsage($memory_usage, $memory_capacity),
        'value' => $memory_usage,
      ];
      $row['pod_usage'] = [
        'data' => $this->k8sService->formatPodUsage($pod_usage, $pod_capacity),
        'value' => $pod_usage,
      ];

      $rows[] = ['data' => $row];
    }

    $headers = [];
    $header_data = [];

    if (!empty($cloud_project)) {
      $header_data['k8s_cluster'] = $this->t('K8s Cluster');
    }
    $header_data += [
      'namespace' => $this->t('Namespace'),
      'costs' => $this->t('Total Costs ($)'),
      'cpu_usage' => $this->t('CPU (Usage)'),
      'memory_usage' => $this->t('Memory (Usage)'),
      'pod_usage' => $this->t('Pods Allocation'),
    ];

    foreach ($header_data ?: [] as $key => $data) {
      $headers[$data->__toString()] = [
        'data' => $data,
        'field' => $key,
      ];
    }

    $sort = !empty($params['sort']) ? $params['sort'] : '';
    $order = !empty($params['order']) ? $params['order'] : '';

    $order_field = NULL;
    foreach ($headers ?: [] as $header) {
      if ($header['data']->render() === $order) {
        $order_field = $header['field'];
      }
    }

    // Get sort and order parameters.
    if (empty($sort)) {
      $sort = 'asc';
    }
    if (empty($order_field)) {
      if (!empty($cloud_project)) {
        $order_field = 'k8s_cluster';
      }
      else {
        $order_field = 'namespace';
      }
    }

    // Sort data.
    usort($rows, static function ($a, $b) use ($sort, $order_field) {
      $result = 1;
      if ($sort === 'desc') {
        $result *= -1;
      }

      if ($order_field === 'k8s_cluster' && $a['data'][$order_field]['data']['#title'] === $b['data'][$order_field]['data']['#title']) {
        $order_field = 'namespace';
        $result = 1;
      }

      if ($order_field === 'k8s_cluster' || $order_field === 'namespace') {
        $result *= $a['data'][$order_field]['data']['#title'] < $b['data'][$order_field]['data']['#title'] ? -1 : 1;
      }
      else {
        $value_a = floatval($a['data'][$order_field]['value']);
        $value_b = floatval($b['data'][$order_field]['value']);
        $result *= $value_a < $value_b ? -1 : 1;
      }

      return $result;
    });

    $items_per_page_options = cloud_get_views_items_options();
    $items_per_page_options['All'] = '- All -';

    $items_per_page
      = !empty($params['items_per_page'])
        && array_key_exists($params['items_per_page'], $items_per_page_options)
        ? $params['items_per_page'] : self::DEFAULT_ITEMS_PER_PAGE;

    $current_rows_chunk = $rows;
    if ($items_per_page !== 'All') {
      // Set pager's ID as 10.
      $current_page = $this->pagerManager
        ->createPager(count($rows), $items_per_page, 10)
        ->getCurrentPage();
      $rows_chunks = array_chunk($rows, $items_per_page);
      $current_rows_chunk = !empty($rows_chunks) ? $rows_chunks[$current_page] : [];
    }

    $table = [
      '#theme' => 'table__k8s_costs',
      '#header' => $headers,
      '#rows' => $current_rows_chunk,
      '#attributes' => [
        'block_id' => $block_id,
      ],
    ];

    $build['k8s_namespace_costs'] = [
      '#type' => 'details',
      '#title' => $this->t('Namespace Costs') . " ($cost_type_list[$cost_type])",
      '#open' => TRUE,
      '#id' => $block_id,
    ];

    $build['k8s_namespace_costs']['container'] = [
      '#type' => 'container',
      '#attributes' => [
        'class' => ['form--inline', 'form-inline', 'clearfix'],
      ],
    ];

    $build['k8s_namespace_costs']['container']['items_per_page'] = [
      '#type' => 'select',
      '#name' => 'items_per_page',
      '#title' => $this->t('Items per page'),
      '#value' => $items_per_page,
      '#options' => $items_per_page_options,
    ];

    $build['k8s_namespace_costs']['container']['cost_type'] = [
      '#type' => 'select',
      '#name' => 'cost_type',
      '#title' => $this->t('Cost Type'),
      '#value' => $cost_type,
      '#options' => $cost_type_list,
    ];

    $build['k8s_namespace_costs']['container']['apply'] = [
      '#type' => 'button',
      '#name' => 'apply',
      '#value' => $this->t('Apply'),
    ];

    $build['k8s_namespace_costs']['table'] = $table;
    if ($items_per_page !== 'All') {
      $build['k8s_namespace_costs']['pager'] = [
        '#type' => 'pager',
        '#element' => 10,
        '#tags' => [
          $this->t('« First'),
          $this->t('‹‹'),
          '',
          $this->t('››'),
          $this->t('Last »'),
        ],
      ];
    }

    $build['#attached']['library'][] = 'k8s/k8s_cost_block';

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge(): bool {
    $this->killSwitch->trigger();
    // BigPipe/#cache/max-age is breaking my block javascript
    // https://www.drupal.org/forum/support/module-development-and-code-questions/2016-07-17/bigpipecachemax-age-is-breaking-my
    // "a slight delay of a second or two before the charts are built.
    // That seems to work, though it is a junky solution.".
    return $this->moduleHandler->moduleExists('big_pipe') ? 1 : 0;
  }

}
